# Release history

## Release 0.8.2 (2021)


## Release 0.8.1 (2021-07-23)

Primarily a bugfix release to fix the SymPy compatability issues as well as improved requirements handling.





(c) Brett G. Olivier, Amsterdam, 2021